/**
  * Prima.java
  * @author  Erick Santillan
  * @version  Abril 2010
  */

import java.io.Serializable;

public  class Prima implements Serializable{
	private double primaRiesgo;
	private double primaNivelada;
	private double intereses;

    /** Cronstructor por parametros
     * @param cliente - cliente para quien se calcula la poliza
     * @param tempSeguro - anios que dura el seguro
     * @param tempPago - anios durante los que se paga el seguro
     * @param intereses - tasa de rendimiento
     */
	public Prima(Persona cliente,int tempSeguro,int tempPago,double intereses){
		this.intereses=intereses=
		primaRiesgo=calculoPRiesgo(cliente, tempSeguro);
		primaNivelada =calculoPNivelada(cliente, tempPago);
    }


    /** Metodo para determinar la prima de riesgo
     *@param cliente - Persona para quien se calcula el seguro
     *@param tempSeguro - anios que dura el seguro
     *@return double - prima que se pagaria por cubir el riesgo
     */
	public double calculoPRiesgo(Persona cliente, int tempSeguro){
	    double prima=0;
	    for(int i =0; i<tempSeguro;i++){
	           prima+=cliente.ProbabilidadMuerte(i)*Math.pow((1/(1+intereses)),i);
	    }
	    return prima;
	}

    /** Metodo para determinar la prima de nivelada, cantidad que se paga cada anio
     *@param cliente - Persona para quien se calcula el seguro
     *@param tempSeguro - anios que dura el seguro
     *@return double - prima que se pagaria cada anio
     */
	public double calculoPNivelada(Persona cliente, int tempPagos){
	    double prima=0;
	    for(int i =0; i<tempPagos;i++){
	      prima+=cliente.ProbabilidadSupervivencia(i)*Math.pow((1/(1+intereses)),(double)i);
	    }
	    prima= primaRiesgo/prima;
	         return prima;
	}

      /**
       *
       *Metodos Obtener y Modificar
       *
       **/

    /** establecerPrimaRiesgo
     *@param prima - prima de riesgo
     */
	   public void establecerPrimaRiesgo(double prima){
		   primaRiesgo=prima;
	   }
    /** obtenerPrimaRiesgo
     *@return double - prima de riesgo
     */
	   public double obtenerPrimaRiesgo(){
		   return primaRiesgo;
	   }

    /** establecerPrimaNivelada
     *@param prima - prima nivelada
     */
	   public void establecerPrimaNivelada(double prima){
		   primaNivelada=prima;
	   }
    /** obtenerPrimaNivlada
     *@return double - prima nivelada
     */
	   public double obtenerPrimaNivelada(){
		   return primaNivelada;
	   }

    /** establecerIntereses
     *@param i - tasa rendimiento
     */
	   public void establecerIntereses(double i){
		   intereses=i;
	   }

    /** obtenerIntereses
     *@return double - tasa de rendimiento
     */
	   public double obtenerIntereses(){
		   return intereses;
	   }

}